﻿using System;

namespace Juniper.Ssi.WM
{
   /// <summary>
   /// The exception thrown when an error occurs in the ssi.
   /// </summary>
   public class SsiException : Exception
   {
       private ErrorCode _ErrorCode;
      /// <summary>
      /// Initializes a new instance of the <see cref="SsiException"/> class.
      /// </summary>
      public SsiException()
      {
      }

      /// <summary>
      /// Initializes a new instance of the <see cref="SsiException"/> class.
      /// </summary>
      /// <param name="errorCode">The error code.</param>
      public SsiException(ErrorCode errorCode)
      {
         ErrorCode = errorCode;
      }

      /// <summary>
      /// Initializes a new instance of the <see cref="SsiException"/> class.
      /// </summary>
      /// <param name="errorCode">The error code.</param>
      /// <param name="message">The message.</param>
      public SsiException(ErrorCode errorCode, string message) : base(message)
      {
         ErrorCode = errorCode;
      }

      /// <summary>
      /// Initializes a new instance of the <see cref="SsiException"/> class.
      /// </summary>
      /// <param name="errorCode">The error code.</param>
      /// <param name="message">The message.</param>
      /// <param name="innerException">The inner exception.</param>
      public SsiException(ErrorCode errorCode, string message, Exception innerException) : base(message, innerException)
      {
         ErrorCode = errorCode;
      }

      /// <summary>
      /// Initializes a new instance of the <see cref="SsiException"/> class.
      /// </summary>
      /// <param name="message">The message.</param>
      public SsiException(string message) : base(message)
      {
      }

      /// <summary>
      /// Initializes a new instance of the <see cref="SsiException"/> class.
      /// </summary>
      /// <param name="message">The error message that explains the reason for the exception.</param>
      /// <param name="innerException">The exception that is the cause of the current exception, or a null reference (Nothing in Visual Basic) if no inner exception is specified.</param>
      public SsiException(string message, Exception innerException) : base(message, innerException)
      {
      }

      /// <summary>
      /// Gets the error code.
      /// </summary>
      public ErrorCode ErrorCode 
      {
          get
          {
              return _ErrorCode;
          }
          private set
          {
              _ErrorCode = value;
          }
      }
   }
}